@@ -26,15 +26,19 @@ sub start_server
   my $class = shift;
   my $opt = { @_ };
   $opt->{handshake} ||= sub {};
+  $opt->{customize_server_response} ||= sub {};
   my $server_cv = AnyEvent->condvar;
 
   tcp_server undef, undef, sub {
     my $handshake = Protocol::WebSocket::Handshake::Server->new;
-    my $frame     = Protocol::WebSocket::Frame->new;
+    my $frame     = Protocol::WebSocket::Frame->new( max_payload_size => 0 );
   
     my $hdl = AnyEvent::Handle->new(
       $opt->{tls} ? (tls => 'accept', tls_ctx => $opt->{tls}) : (),
       fh => shift,
+      on_eof => sub {
+        note("testlib::Server: on_eof called.");
+      }
     );
   
     $hdl->on_read(
@@ -46,6 +50,7 @@ sub start_server
           $handshake->parse($chunk);
           if($handshake->is_done)
           {
+            $opt->{customize_server_response}->($handshake);
             $hdl->push_write($handshake->to_string);
             $opt->{handshake}->(handshake => $handshake, hdl => $hdl);
           }
@@ -81,7 +86,8 @@ sub start_echo
     
     return if !$opt->{frame}->is_text && !$opt->{frame}->is_binary;
 
-    $opt->{hdl}->push_write($opt->{frame}->new($opt->{message})->to_bytes);
+    
+    $opt->{hdl}->push_write($opt->{frame}->new(buffer => $opt->{message}, max_payload_size => 0 )->to_bytes);
         
     if($opt->{message} eq 'quit')
     {
